/*********************************************
*	Author: Chris @ PyroElectro.com
*	Date: 4/11/2012
*
*	Description: This firmware setups up the PIC's USART
*	for transmit, and opens the ADCs. Then it consistently
*	captures the ADC value on RA0 and RA1, encodes the value
*	and then transmits it out the USART port.
*
*	For Full Details On This Firmware Please
*	Visit: http://www.pyroelectro.com/tutorials/xbee_dual_dc_motor_control/
*********************************************/

#include <p18f4520.h>
#include <delays.h>
#include <usart.h>
#include <adc.h>

#pragma config OSC 		= HS
#pragma config WDT      = OFF
#pragma config LVP      = OFF

void main(void){

unsigned int result = 0;
unsigned int data = 0;

TRISB=0x01;
TRISD=0x80;

  // configure USART

  OpenUSART( USART_TX_INT_OFF  &
             USART_RX_INT_OFF  &
             USART_ASYNCH_MODE &
             USART_EIGHT_BIT   &
             USART_CONT_RX     &
             USART_BRGH_HIGH, 129);


while(1){

data = 0;

/************* Convert Channel 0 *****************/
OpenADC(ADC_FOSC_32 & ADC_RIGHT_JUST & ADC_20_TAD, ADC_CH0 & 
ADC_INT_OFF & ADC_VREFPLUS_VDD & ADC_VREFMINUS_VSS, 0);
//Convrt A/D
Delay10TCYx( 5 ); // Delay for 50TCY
ConvertADC(); // Start conversion
//Read A/D
while( BusyADC()); // Wait for completion
	result = (ReadADC()); // Read result
Delay10TCYx(5);
CloseADC(); // Disable A/D converter 
/************* ***************** *****************/

data += (result>>6);

/************* Convert Channel 1 *****************/
OpenADC(ADC_FOSC_32 & ADC_RIGHT_JUST & ADC_20_TAD, ADC_CH1 & 
ADC_INT_OFF & ADC_VREFPLUS_VDD & ADC_VREFMINUS_VSS, 0);
//Convrt A/D
Delay10TCYx( 5 ); // Delay for 50TCY
ConvertADC(); // Start conversion
//Read A/D
while( BusyADC() ); // Wait for completion
	result = (ReadADC()); // Read result
Delay10TCYx(5);
CloseADC(); // Disable A/D converter 
/************* ***************** *****************/

data += (result&0b1111000000)>>2;

Delay10KTCYx(5);
putcUSART( data );
}

CloseUSART();
}



